<?php

namespace Drupal\inline_all_css\Asset;

use Drupal\Core\Asset\AssetCollectionRendererInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Render\Markup;
use function file_get_contents;

/**
 * Decorates the CSS collection renderer service, adds Critical CSS.
 *
 * @see \Drupal\Core\Asset\CssCollectionRenderer
 */
class CriticalCssCollectionRenderer implements AssetCollectionRendererInterface {

  /**
   * The filesystem service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a CriticalCssCollectionRenderer.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system service.
   */
  public function __construct(FileSystemInterface $file_system) {
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public function render(array $assets) {
    $css = '';
    foreach ($assets as $asset) {
      $file = $this->fileSystem->realpath($asset['data']);
      $css .= file_get_contents($file);
    }

    return [
      [
        '#type' => 'html_tag',
        '#tag' => 'style',
        '#value' => Markup::create($css),
      ],
    ];
  }

}
